Changelog
=========

0.3.1 (2016-06-22)
------------------

* Fixed issue #1 prevented generated __repr__ methods to work in mutithreaded programs.

0.3.0 (2016-06-20)
------------------

* Now ``make_repr`` can be used for recursive datastructures.

0.2.1 (2016-06-19)
------------------

* Documentation improved.

0.2.0 (2016-06-19)
------------------

* Better handling of nested datastructure.
* Callables as source of the attribute's value.
* Some documentation.

0.1.0 (2016-06-09)
------------------

* First release on PyPI.
